Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(124)

Unified Diff: components/browser_sync/profile_sync_service.h

Issue 2458013002: [Sync] Rename ModelTypeService to ModelTypeSyncBridge. (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/browser_sync/profile_sync_service.h
diff --git a/components/browser_sync/profile_sync_service.h b/components/browser_sync/profile_sync_service.h
index d6a64a3a411ff2700f9b450159d4a6a4dbfdbf2e..460ace4970a2debe117d16d1d3b59824fe8128fa 100644
--- a/components/browser_sync/profile_sync_service.h
+++ b/components/browser_sync/profile_sync_service.h
@@ -345,8 +345,8 @@ class ProfileSyncService : public syncer::SyncService,
// Returns the SyncableService for syncer::DEVICE_INFO.
virtual syncer::SyncableService* GetDeviceInfoSyncableService();
- // Returns the ModelTypeService for syncer::DEVICE_INFO.
- virtual syncer::ModelTypeService* GetDeviceInfoService();
+ // Returns the ModelTypeSyncBridge for syncer::DEVICE_INFO.
+ virtual syncer::ModelTypeSyncBridge* GetDeviceInfoService();
// Returns synced devices tracker.
virtual syncer::DeviceInfoTracker* GetDeviceInfoTracker() const;
@@ -958,7 +958,7 @@ class ProfileSyncService : public syncer::SyncService,
std::unique_ptr<syncer::LocalDeviceInfoProvider> local_device_;
// Locally owned SyncableService and ModelTypeService implementations.
std::unique_ptr<sync_sessions::SessionsSyncManager> sessions_sync_manager_;
std::unique_ptr<syncer::DeviceInfoSyncService> device_info_sync_service_;
std::unique_ptr<syncer::DeviceInfoService> device_info_service_;
@@ -958,7 +958,7 @@ class ProfileSyncService : public syncer::SyncService,
std::unique_ptr<syncer::LocalDeviceInfoProvider> local_device_;
- // Locally owned SyncableService and ModelTypeService implementations.
+ // Locally owned SyncableService and ModelTypeSyncBridge implementations.
std::unique_ptr<sync_sessions::SessionsSyncManager> sessions_sync_manager_;
std::unique_ptr<syncer::DeviceInfoSyncService> device_info_sync_service_;

Powered by Google App Engine
This is Rietveld 408576698